# -*- coding: utf-8 -*-
# __init__.py
# Copyright (c) 2025 zedmoster
# Revit integration through the Model Context Protocol.

__name__ = "revit-mcp"
__author__ = "zedmoster"
__version__ = "0.5.15"
__license__ = "MIT"
__copyright__ = "Copyright (c) 2025 zedmoster"
__description__ = "Revit integration through the Model Context Protocol."
__url__ = "https://www.zedmoster.cn"
__credits__ = ["zedmoster"]
__status__ = "Development"
__maintainer__ = "zedmoster"
__docformat__ = "restructuredtext"
__keywords__ = "revit, mcp, model context protocol, revit-mcp, zedmoster"

from .server import main
